from bobsleigh.conf.handlers import InstallationHandler
from collections import OrderedDict
import socket


class WebfactionHandler(InstallationHandler):

    def get_required_kwargs(self):
        required_kwargs = super(WebfactionHandler, self).get_required_kwargs()
        required_kwargs += (
           # Name of the webfaction user
           'webfaction_user',
           'server_email',
        )
        return required_kwargs

    def get_optional_kwargs(self):
        optional_kwargs = super(WebfactionHandler, self).get_optional_kwargs()
        optional_kwargs.update({
            'email_host': 'smtp.webfaction.com',
        })
        return optional_kwargs

    def get_config_patterns(self):
        # Because some of the items depend on the setting of ones before,
        # this needs to be an OrderedDict.
        return (
            ('log_path', '/home/%(webfaction_user)s/logs/user/%(sitename)s'),
            ('static_path', '/home/%(webfaction_user)s/webapps/%(sitename)s_static'),
            ('media_path', '/home/%(webfaction_user)s/webapps/%(sitename)s_uploads'),
            ('virtualenv_path', '/home/%(webfaction_user)s/.virtualenvs/%(sitename)s'),
            ('project_path', '/home/%(webfaction_user)s/webapps/%(sitename)s/project'),
            # Set the ability to have a prefixed name - this will
            # be used in place of the sitename for email and database creds
            ('prefixed_name', '%(sitename)s'),
            ('email_host_user', '%(prefixed_name)s'),
            ('db_name', '%(prefixed_name)s'),
            ('db_user', '%(prefixed_name)s'),
        )

    def is_current(self):
        """Webfaction-specific way of detecting whether this
        is the current installation, since several installations
        running on one host."""
        if self.config.host == socket.gethostname():
            # Check if virtualenv matches
            virtualenv_path = '/'.join(__file__.split('/')[:5])
            return virtualenv_path == self.config.virtualenv_path
        return False


class DevHandler(WebfactionHandler):
    def get_optional_kwargs(self):
        optional_kwargs = super(DevHandler, self).get_optional_kwargs()
        optional_kwargs.update({
            'debug': True,
        })
        return optional_kwargs


class LiveHandler(WebfactionHandler):
    pass



from bobsleigh.conf.handlers import InstallationHandler


class LocalHandler(InstallationHandler):
    "For my local development setup."

    def get_required_kwargs(self):
        return ('sitename',)

    def get_optional_kwargs(self):
        optional_kwargs = super(LocalHandler, self).get_optional_kwargs()
        optional_kwargs.update({
            'host': 'lanky',
        })
        return optional_kwargs

    def get_config_patterns(self):
        patterns = super(LocalHandler, self).get_config_patterns()
        patterns += (
            ('domain', '%(sitename)s.localhost'),
            ('db_name', '%(sitename)s'),
            ('db_user', '%(sitename)s'),
            ('log_path', '/var/log/django/%(sitename)s'),
            ('static_path', '/home/david/var/www/%(sitename)s/static'),
            ('media_path', '/home/david/var/www/%(sitename)s/uploads'),
            ('virtualenv_path', '/home/david/.virtualenvs/%(sitename)s'),
            ('project_path', '/home/david/www/%(sitename)s'),
        )
        return patterns


class VagrantHandler(InstallationHandler):
    "Geared up towards Vagrant machines."

    def get_required_kwargs(self):
        required_kwargs = super(VagrantHandler, self).get_required_kwargs()
        required_kwargs += 'sitename'
        return required_kwargs

    def get_optional_kwargs(self):
        optional_kwargs = super(LocalHandler, self).get_optional_kwargs()
        optional_kwargs.update({
            'host': 'precise32',
        })
        return optional_kwargs

    def get_config_patterns(self):
        patterns = super(LocalHandler, self).get_config_patterns()
        patterns += (
            ('domain', '%(sitename)s.vagrant'),
            ('db_name', '%(sitename)s'),
            ('db_user', '%(sitename)s'),
            ('log_path', '/var/log/django'),
            ('static_path', '/opt/site/static'),
            ('media_path', '/opt/site/uploads'),
            ('virtualenv_path', '/opt/site/.virtualenvs/site'),
            ('project_path', '/opt/site/django'),
        )
        return patterns



from distutils.core import setup
from setuptools import find_packages


setup(
    name='bobsleigh_seddonym',
    version='0.1',
    url='http://github.com/seddonym/bobsleigh-seddonym/',
    author='David Seddon',
    author_email='david@seddonym.me',
    description='Helpful Bobsleigh settings for my projects.',
    packages=find_packages(),
    include_package_data=True,
)



"""Base settings shared by all environments.
This is a reusable basic settings file.
"""
from django.conf.global_settings import *
import os
import sys
import re

# Local time zone for this installation. Choices can be found here:
# http://en.wikipedia.org/wiki/List_of_tz_zones_by_name
TIME_ZONE = 'GB'
USE_TZ = True
USE_I18N = True
USE_L10N = True
LANGUAGE_CODE = 'en-GB'
LANGUAGES = (
    ('en-GB', 'British English'),
)
SITE_ID = 1
LOGIN_URL = '/login/'
LOGOUT_URL = '/logout/'
LOGIN_REDIRECT_URL = '/'

STATIC_URL = '/static/'
MEDIA_URL = '/uploads/'

ADMINS = (
    ('David Seddon', 'david@seddonym.me'),
)
MANAGERS = ADMINS

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.postgresql_psycopg2',
    }
}

LOGGING = {
    'version': 1,
    'disable_existing_loggers': False,
    'formatters': {
        'standard': {
            'format' : "[%(asctime)s] %(levelname)s [%(name)s:%(lineno)s] %(message)s",
            'datefmt' : "%d/%b/%Y %H:%M:%S"
        },
    },
    'handlers': {
        'error': {
            'level':'ERROR',
            'class':'logging.handlers.RotatingFileHandler',
            # 'filename': ERROR_LOG_PATH, - filled in by handler
            'maxBytes': 50000,
            'backupCount': 2,
            'formatter': 'standard',
        },
        'debug': {
            'level':'DEBUG',
            'class':'logging.handlers.RotatingFileHandler',
            # 'filename': DEBUG_LOG_PATH, - filled in by handler
            'maxBytes': 50000,
            'backupCount': 2,
            'formatter': 'standard',
        },
        'mail_admins': {
            'level': 'ERROR',
            'class': 'django.utils.log.AdminEmailHandler',
            'include_html': True,
        },
    },
    'loggers': {
        'django': {
            'handlers':['error'],
            'propagate': True,
            'level':'DEBUG',
        },
        'django.request': {
            'handlers': ['mail_admins', 'error'],
            'level': 'ERROR',
            'propagate': False,
        },
        'project': {
            'handlers':['debug'],
            'propagate': True,
            'level':'DEBUG',
        },
    }
}

TEMPLATE_CONTEXT_PROCESSORS += (
    'django.core.context_processors.request',
)

ROOT_URLCONF = 'urls'

INSTALLED_APPS = (
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.sites',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'django.contrib.admin',
)

MIDDLEWARE_CLASSES = (
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
)